/*********************************************************************
|*
|*  Version:    1.2
|*
|*  Description:
|*
|*      TASKING M16C ROM Monitor: commands and arror codes
|*
|*  Copyright 2003 Altium BV
|*
 *********************************************************************/

#ifndef _COMMAND_H
#define _COMMAND_H

#include <setjmp.h>

/*
 * defines, typedefs, enums
 */
#define CTRL_ESC    0x1B
#define CTRL_SP     ' '
#define CTRL_INIT   '!'
#define CTRL_START  '('
#define CTRL_END    ')'
#define CTRL_RCVE   '.'
#define CTRL_BATSTA '['
#define CTRL_BATEND ']'

#define CMD_CONF    0x00 /* + */
#define CMD_DEBUG   0x01 /* + */
#define CMD_REST    0x07 /* + */
#define CMD_CLR     0x08 /* + */
#define CMD_DWNH    0x0B /* + */
#define CMD_PB      0x20 /* + */
#define CMD_PBCL    0x21 /* + */
#define CMD_GB      0x33 /* + */
#define CMD_PROG    0x34 /* + */
#define CMD_STOP    0x35 /* + */
#define CMD_STEP    0x38 /* + */
#define CMD_XREG    0x40 /* + */
#define CMD_DUMP    0x41 /* + */
#define CMD_FILL    0x42 /* + */
#define CMD_FM      0x3E /* + */

#define CMD_UNKNOWN 0xFF /* */

#define ERR_NORMAL      '0'
#define ERR_CHECKSUM    '2'
#define ERR_EXEC        '4'
#define SYNTAX_ERROR    '8'
#define ERR_NOTBREAK    'H'
#define ERR_IRREGULAR   'L'
#define ERR_PGM_STOPPED 'S'

#define DOWNLOADBUFSIZE     512

/*
 * defines, typedefs
 */
typedef void (*t_function)( void );

typedef struct func_map
{
    unsigned char func_name;
    t_function func_ptr;
} FUNC_MAP_T;


/*
 * global functions, inline functions
 */
extern unsigned char cmd_process_byte(unsigned char c, unsigned char nibble );
extern void          cmd_handle_command( void );
extern void          cmd_show_conf( void );

/*
 * global variables
 */
extern __near char err_code[3];                          /* keep track of the "error" status */
extern __near t_function cmd_handle;                     /* function pointer to current running command */
#ifdef HAS_4BREAKPOINTS
extern volatile __near unsigned long break_points[4];    /* internal breakpoints, high bit set: available */
#else /* HAS_4BREAKPOINTS */
extern volatile __near unsigned long break_points[2];    /* internal breakpoints, high bit set: available */
#endif /* HAS_4BREAKPOINTS */
extern __near unsigned long val56;
extern __near unsigned int  val4;
extern __near unsigned char val2;
extern __near jmp_buf env;
extern __near unsigned char  downloadbuf[DOWNLOADBUFSIZE];
extern __near unsigned char * __near downloadptr;
           
#endif /* _COMMAND_H */
